==> haskell-xml-conduit-1.9.1.4-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-conduit
version:              1.9.1.4
visibility:           public
id:                   xml-conduit-1.9.1.4-5Skvz2pSEQwBW23AfjaET7
key:                  xml-conduit-1.9.1.4-5Skvz2pSEQwBW23AfjaET7
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  941200d9636578401de5d22b850f0f8d
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-conduit
hs-libraries:         HSxml-conduit-1.9.1.4-5Skvz2pSEQwBW23AfjaET7
depends:
    attoparsec-0.14.4-CZt0qAnGZHQHCYZEsndAye base-4.17.2.1
    blaze-html-0.9.2.0-EVafAfeFFsi6uTiWDNT8VW
    blaze-markup-0.8.3.0-5DZhbkei3UTFzR0H9aIui1 bytestring-0.11.5.3
    conduit-1.3.6.1-4gghCzlDHkwDP6CgdQyket
    conduit-extra-1.3.8-G9lFzvhsWCC98MvCUjkory containers-0.6.7
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM deepseq-1.4.8.0
    resourcet-1.2.6-AVTqnIhFfb1JoG6KRaDalG text-2.0.2
    transformers-0.5.6.2 xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.9.1.4-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-conduit
version:              1.9.1.4
visibility:           public
id:                   xml-conduit-1.9.1.4-9qJKdGu3l2l3pZHQcKHKoy
key:                  xml-conduit-1.9.1.4-9qJKdGu3l2l3pZHQcKHKoy
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  1a4c01a24ff7dfab8e37260f67d04fcc
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-conduit
hs-libraries:         HSxml-conduit-1.9.1.4-9qJKdGu3l2l3pZHQcKHKoy
depends:
    attoparsec-0.14.4-HrmGc7uWcHZBxPSUhHwhWb base-4.17.2.1
    blaze-html-0.9.2.0-B9ruHJfpRcR5JjuSNAaIt4
    blaze-markup-0.8.3.0-5FWKxPQWriR2jdJTxmXBeL bytestring-0.11.5.3
    conduit-1.3.6.1-13kifNr5M5JAEtUuZRI8Tz
    conduit-extra-1.3.8-Z3oKkUHnho6cPgZd14hsr containers-0.6.7
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM deepseq-1.4.8.0
    resourcet-1.2.6-KrqOxZFO9SkCFTXD2zqz38 text-2.0.2
    transformers-0.5.6.2 xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
